# mkdocs-jupyter Change Log

## 0.24.3

- Fix theme selection

## 0.24.1

- Fix TOC header links

## 0.24.0

- Add option for including requireJS
- Add option for custom highlight CSS classes
- Make execute_ignore a list
- Fix various CSS issues

## 0.23.0

- Support nbconvert 7

## 0.21.0

- Support Pygments 2.1.0
- Fix some markdown CSS overflow issues

## 0.20.1

- Remove ipython_genutils dependency (#70) by: @incentsarago

## 0.20.0

- Support for toggle themes in material
- Use poetry 1.1.X

## 0.19.0

- Support mkdocs-material 8

## 0.18.1

- Support multiple languages syntax highlighting

## 0.18.0

- Support Jupyter themes
- Option to ignore some notebooks to be executed
- Add copy to clipboard button to cells

## 0.17.0

- Support Python 3.9
- Use new JupyterLab template as base

## 0.16.0

- Support plain Python `.py` using Jupytext

## 0.15.0

- Support nbconvert 6.0.0

## 0.13.0

- Fixed TOC in mkdocs 1.1.0
- Added the ability to include the source notebooks as part of the build
